==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframepaletteselectionbase.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with palette control. This class is abstract to allow for
//  various ways to specify the palette.
//

#ifndef IGGFRAMEPALETTESELECTIONBASE_H
#define IGGFRAMEPALETTESELECTIONBASE_H


#include "iggframe.h"


#include "iarray.h"

class iPalette;


class iggFramePaletteSelectionBase : public iggFrame
{

public:

	iggFramePaletteSelectionBase(bool witheditor, iggFrame *parent);
	virtual ~iggFramePaletteSelectionBase();

	virtual iPalette* GetCurrentPalette() const = 0; // this non-symmetric form is more versatile

	void SetCurrentPaletteIndex(int n);
	inline int GetCurrentPaletteIndex() const { return mCurrentPaletteIndex; }

	static void UpdateAll();

protected:

	virtual void SetCurrentPaletteIndexBody(int n) = 0;

	static iPointerArray<iggFramePaletteSelectionBase>& List();
	int mCurrentPaletteIndex;
};

#endif  // IQTFRAMEPALETTESELECTIONBASE_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggframepaletteselectionbase.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with palette control. This class is abstract to allow for
//  various ways to specify the palette.
//

#ifndef IGGFRAMEPALETTESELECTIONBASE_H
#define IGGFRAMEPALETTESELECTIONBASE_H


#include "iggframe.h"


#include "iarray.h"

class iPalette;


class iggFramePaletteSelectionBase : public iggFrame
{

public:

	iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent);
	virtual ~iggFramePaletteSelectionBase();

	virtual iPalette* GetCurrentPalette() const = 0; // this non-symmetric form is more versatile

	void SetCurrentPaletteIndex(int n);
	inline int GetCurrentPaletteIndex() const { return mCurrentPaletteIndex; }

	static void UpdateAll();

protected:

	virtual void SetCurrentPaletteIndexBody(int n) = 0;

	static iPointerArray<iggFramePaletteSelectionBase>& List();
	int mCurrentPaletteIndex;
};

#endif  // IQTFRAMEPALETTESELECTIONBASE_H
